#
# spec file for package mcstrans
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mcstrans
Version:        3.8.1
Release:        1.1
Summary:        SELinux Translation Daemon
License:        GPL-2.0-or-later
Group:          System/Management
URL:            https://github.com/SELinuxProject/selinux/wiki
Source0:        https://github.com/SELinuxProject/selinux/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        https://github.com/SELinuxProject/selinux/releases/download/%{version}/%{name}-%{version}.tar.gz.asc
Source2:        mcstrans.keyring
Patch2:         harden_mcstrans.service.patch
BuildRequires:  aaa_base
BuildRequires:  libcap-devel
BuildRequires:  libselinux-devel >= 1.30.3
BuildRequires:  libsepol-devel-static
BuildRequires:  pcre-devel
BuildRequires:  pkgconfig(systemd)
Requires:       aaa_base
Provides:       setransd
%{?systemd_requires}

%description
Security-enhanced Linux is a feature of the Linux kernel and a number
of utilities with enhanced security functionality designed to add
mandatory access controls to Linux.  The Security-enhanced Linux
kernel contains new architectural components originally developed to
improve the security of the Flask operating system. These
architectural components provide general support for the enforcement
of many kinds of mandatory access control policies, including those
based on the concepts of Type Enforcement, Role-based Access
Control, and Multi-level Security.

mcstrans provides a translation daemon to translate SELinux categories
from internal representations to user defined representation.

%prep
%setup -q
%patch -P2 -p1

%build
export CFLAGS="%{optflags}"
make LIBDIR="%{_libdir}" %{?_smp_mflags}

%install
mkdir -p %{buildroot}/%{_lib}
mkdir -p %{buildroot}/%{_libdir}
mkdir -p %{buildroot}/%{_unitdir}
%make_install LIBDIR="%{buildroot}%{_libdir}" SHLIBDIR="%{buildroot}/%{_lib}"
rm -f %{buildroot}%{_sbindir}/*
rm -f %{buildroot}%{_libdir}/*.a
rm %{buildroot}%{_sysconfdir}/rc.d/init.d/mcstrans*
rm -rf %{buildroot}%{_sysconfdir}/rc.d
mkdir -p %{buildroot}%{_datadir}/doc/packages/%{name}
cp -r share/examples %{buildroot}%{_datadir}/doc/packages/%{name}
mkdir -p %{buildroot}%{_sbindir}
ln -sv %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
mv %{buildroot}/sbin/mcstransd %{buildroot}/usr/sbin/mcstransd

%post
%service_add_post mcstrans.service

%preun
%service_del_preun mcstrans.service

%postun
%service_del_postun mcstrans.service

%pre
%service_add_pre mcstrans.service

%files
%{_unitdir}/mcstrans*.service
/usr/sbin/mcstransd
%{_sbindir}/rcmcstrans
%{_mandir}/man5/*.5%{?ext_man}
%{_mandir}/man8/*.8%{?ext_man}
%dir %{_datadir}/doc/packages/%{name}
%{_datadir}/doc/packages/%{name}/*

%changelog
* Fri Mar  7 2025 Cathy Hu <cathy.hu@suse.com>
- Update to version 3.8.1
  https://github.com/SELinuxProject/selinux/releases/tag/3.8.1
  * no source change
* Tue Feb  4 2025 Robert Frohl <rfrohl@suse.com>
- Update to version 3.8
  https://github.com/SELinuxProject/selinux/releases/tag/3.8
  * No functional changes
- For a more in depth list of changes see
  https://github.com/SELinuxProject/selinux/releases/download/3.8/shortlog-3.8.txt
- keyring: Update Petr Lautrbach <lautrbach@redhat.com>
  * removed 0xBC3905F235179CF1 (expired: 2024-10-25)
  * added 0xFB4C685B5DC1C13E (expires: 2026-11-04)
* Mon Jul  1 2024 Cathy Hu <cathy.hu@suse.com>
- Update to version 3.7
  https://github.com/SELinuxProject/selinux/releases/tag/3.7
  * Bugfixes:
  * mcstrans: free constraint in error branch
  * mcstrans: ensure transitivity in compare functions
  * mcstrans: check memory allocations
* Tue Dec 19 2023 Cathy Hu <cathy.hu@suse.com>
- Update to version 3.6
  https://github.com/SELinuxProject/selinux/releases/tag/3.6
  * Add notself support for neverallow rules
  * Improve man pages
  * man pages: Remove the Russian translations
  * Add notself and other support to CIL
  * Add support for deny rules
  * Translations updated from
    https://translate.fedoraproject.org/projects/selinux/
  * Bug fixes
- Remove keys from keyring since they expired:
  - E853C1848B0185CF42864DF363A8AD4B982C4373
    Petr Lautrbach <plautrba@redhat.com>
  - 63191CE94183098689CAB8DB7EF137EC935B0EAF
    Jason Zaman <jasonzaman@gmail.com>
- Add key to keyring:
  - B8682847764DF60DF52D992CBC3905F235179CF1
    Petr Lautrbach <lautrbach@redhat.com>
* Mon Nov 27 2023 Hu <cathy.hu@suse.com>
- Change deprecated `%%patch1 -p1` syntax to supported `%%patch -P1 -p1`
  (bsc#1216669)
* Fri Feb 24 2023 Johannes Segitz <jsegitz@suse.com>
- Update to version 3.5
  * preserve runtime directory
- Refreshed harden_mcstrans.service.patch
- Added additional developer key (Jason Zaman)
* Mon May  9 2022 Johannes Segitz <jsegitz@suse.com>
- Update to version 3.4
  * Port to PCRE2
- Dropped patches
  * add_includes.patch: Upstream
  * mcstrans-writepid.patch: Upstream
* Thu Nov 25 2021 Johannes Segitz <jsegitz@suse.com>
- Finish UsrMerge (bsc#1191075)
* Thu Nov 11 2021 Johannes Segitz <jsegitz@suse.com>
- Update to version 3.3
  * No user-visible changes
* Wed Oct  6 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_mcstrans.service.patch
* Tue Mar  9 2021 Johannes Segitz <jsegitz@suse.com>
- Update to version 3.2
  * No user-visible changes, only version bump.
* Tue Jul 14 2020 Johannes Segitz <jsegitz@suse.com>
- Update to version 3.1
  * fix memory leak in new_context_str
* Tue Mar  3 2020 Johannes Segitz <jsegitz@suse.de>
- Update to version 3.0
  * Add reference to setools.conf man page in the daemon one
* Tue Aug 27 2019 Jan Engelhardt <jengelh@inai.de>
- Avoid use of ®/™ signs in specfiles as per guidelines.
* Wed Jun 12 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut the build queues by allowing usage of systemd-mini
* Wed Mar 20 2019 jsegitz@suse.com
- Update to version 2.9
  * Fix check in raw_color()
  * remove unused getpeercon_raw() call
* Tue Dec  4 2018 Jan Engelhardt <jengelh@inai.de>
- One grammar fix, and use %%make_install.
* Fri Nov 23 2018 jsegitz@suse.com
- Dropped mcstransd.service, use the provided service file
- Install example configs
- Fixed source URL
* Wed Oct 17 2018 jsegitz@suse.com
- Update to version 2.8 (bsc#1111732)
  For changes please see
  https://raw.githubusercontent.com/wiki/SELinuxProject/selinux/files/releases/20180524/RELEASE-20180524.txt
- Renamed mcstrans-2.7-writepid.patch to mcstrans-writepid.patch
* Wed May 16 2018 mcepl@suse.com
- Rebase to 2.7
  For changes please see
  https://raw.githubusercontent.com/wiki/SELinuxProject/selinux/files/releases/20170804/RELEASE-20170804.txt
- Renamed mcstrans-0.3.3-writepid.patch to
  mcstrans-2.7-writepid.patch
* Tue Sep  5 2017 jsegitz@suse.com
- Added add_includes.patch to add additional includes and fix
  Factory build
* Wed Jun 17 2015 jsegitz@novell.com
- fixed wrong label in /run preventing startup
* Mon Sep  8 2014 jsegitz@suse.com
- altered package to use systemd. Removed
  mcstrans-0.3.3-initscript.patch since it's no longer necessary
- added mcstrans-0.3.3-writepid.patch to write pid files to the
  correct location
* Mon Dec 10 2012 meissner@suse.com
- provide setransd, like in redhat (covered by mcstrans these days)
* Tue Aug  7 2012 meissner@suse.com
- updated to 0.3.3 , tarball taken from redhat source rpm.
* Thu Apr  5 2012 dvaleev@suse.com
- add LIBDIR, so ppc and ppc64 can build
* Mon Mar 26 2012 vcizek@suse.com
- removed use of /var/lock/subsys in init script [bnc#714633]
* Mon May  3 2010 prusnak@suse.cz
- create /var/run/setrans directory in initscript [Feature#303793]
* Thu Jul 16 2009 prusnak@suse.cz
- remove check and rename from %%post section (not needed)
* Tue Jun 23 2009 prusnak@suse.cz
- require libsepol-devel-static
* Wed May 27 2009 prusnak@suse.cz
- updated to 0.3.1
  * Add inverse bit support
  * Add color support from Eamon Walsh
* Thu Oct 16 2008 prusnak@suse.cz
- created package (version 0.2.11)
